@@ -364,11 +364,11 @@ class LambdaToElasticSearchAndKibanaProps:
         :summary: The properties for the CognitoToApiGatewayToLambda Construct
         '''
         if isinstance(es_domain_props, dict):
-            es_domain_props = CfnDomainProps(**es_domain_props)
+            es_domain_props = aws_cdk.aws_elasticsearch.CfnDomainProps(**es_domain_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = FunctionProps(**lambda_function_props)
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(vpc_props, dict):
-            vpc_props = VpcProps(**vpc_props)
+            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         if __debug__:
             type_hints = typing.get_type_hints(LambdaToElasticSearchAndKibanaProps.__init__)
             check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
